##  DATA ANALYSIS FILES FOR "CAN WAR FOSTER COOPERATION?" 
##  BY BAUER, BLATTMAN, CHYTILOVA, HENRICH, MIGUEL AND MITTS (2016)
##  APRIL 2016

## INSTRUCTIONS 
##	1. Copy the full replication folder to your computer 
##	2. Update the working directory below to point to the replication folder on your computer.
##	3. All results will be saved in your replication folder under the subfolder Results.

## TABLE OF CONTENTS
## 1) Load estimations from each study's analysis
## 2) Main results table
## 3) Create a map
## 4) Create main figures
## 5) Test for whether differences in-group vs. out-group are significant
## 6) Additional results: using alternate (standardizd) measures of violence exposure
## 7) Heterogeneity


rm(list=ls())

install.packages(c("foreign", "metafor", "xtable"), dependencies=T)

library(foreign)
library(metafor)
library(xtable)


setwd("~/Downloads/Replication/") ## Change this directory as needed


# 1) Load estimations from each study's analysis:
#--#--#--#--#--#--#--#--#--#--#--#--#--#--#--#--#

# 1. A standardized measure of each paper's main exposure variable

file_names1 <- list.files("Temp/viol_exp_std/")

results_viol_exp_std <- list()
for (i in 1:length(file_names1)){
	results_viol_exp_std[[i]] = read.dta(paste0("Temp/viol_exp_std/", file_names1[i]))
}
names(results_viol_exp_std) <- file_names1


# 2. A standardized variable of personal exposure to violence

file_names2 <- list.files("Temp/viol_exp_personal_std/")

results_viol_exp_personal_std <- list()
for (i in 1:length(file_names2)){
	results_viol_exp_personal_std[[i]] = read.dta(paste0("Temp/viol_exp_personal_std/", file_names2[i]))
}
names(results_viol_exp_personal_std) <- file_names2


# 3. A standardized variable of household/community exposure to violence

file_names3 <- list.files("Temp/viol_exp_community_std/")

results_viol_exp_community_std <- list()
for (i in 1:length(file_names3)){
	results_viol_exp_community_std[[i]] = read.dta(paste0("Temp/viol_exp_community_std/", file_names3[i]))
}
names(results_viol_exp_community_std) <- file_names3

# 4. A binary measure of each paper's main exposure variable

file_names4 <- list.files("Temp/viol_exp_dummy/")

results_viol_exp_dummy <- list()
for (i in 1:length(file_names4)){
	results_viol_exp_dummy[[i]] = read.dta(paste0("Temp/viol_exp_dummy/", file_names4[i]))
}
names(results_viol_exp_dummy) <- file_names4


# 2) Main results table
#--#--#--#--#--#--#--#--#

source("Code/2.main_table.R")
source("Code/3.main_table_with_crime.R")

# 3) Create a map
#--#--#--#--#--#--#

source("Code/4.map.R")

# 4) Create main figures
#--#--#--#--#--#--#--#--#

source("Code/5.main_graph.R")
source("Code/6.ingroup_outgroup_graph.R")

# 5) Test for whether differences in-group vs. out-group are significant
#--#--#--#--#--#--#--#--#--#--#--#--#--#--#--#--#--#--#--#--#--#--#--#--#

source("Code/7.ingroup_outgroup_test.R")


# 6) Additional results: using alternate (standardized) measures of violence exposure
#--#--#--#--#--#--#--#--#--#--#--#--#--#--#--#--#--#--#--#--#--#--#--#--#--#--#--#--#

source("Code/8.additional_results.R")

# 7) Heterogeneity
#--#--#--#--#--#--#

source("Code/9.heterogeneity.R")


