library(gplots)

# Without crime violence

main_results <- read.csv("Results/Tables/main_results_percise.csv")
main_results_no_index <-  main_results[main_results$outcome!="prosocial_index",]
main_results_index_only <- main_results[main_results$outcome=="prosocial_index",]

main_results_reordered <- rbind(main_results_index_only, main_results_no_index)


main_results_no_inoutgroup <- main_results_reordered[!(main_results_reordered$outcome %in% c("trust_ingroup", "trust_outgroup", "games_ingroup", "games_outgroup")) ,]

labs <- c("Summary \nindex", "Social \ngroup \nparticipation","Community \nleadership/ \nparticipation", "Trust", "Prosocial in \nexperimental \ngames", "Voting", "Knowledge/ \ninterest \nin politics")

pdf("Results/Figures/main_results_no_crime.pdf", width=9, height=5)

par(mar=c(5,4,2,2))
plotCI(x= main_results_no_inoutgroup$beta_for_graph, ui= main_results_no_inoutgroup$ci.ub_for_graph, li= main_results_no_inoutgroup$ci.lb_for_graph, type="p", pt.bg= c("blue3", "forestgreen", "blue3", "forestgreen", "blue3", "forestgreen", "blue3", "forestgreen", "blue3", "forestgreen", "blue3", "forestgreen", "blue3", "forestgreen") , col=c("blue3", "forestgreen", "blue3", "forestgreen", "blue3", "forestgreen", "blue3", "forestgreen", "blue3", "forestgreen", "blue3", "forestgreen", "blue3", "forestgreen"), pch=c(21, 15, 21, 15, 21, 15, 21, 15, 21, 15, 21, 15, 21, 15), gap=0, xaxt="n", ylab="Effect of exposure to violence (sd units)", xlab="", cex.main=1, cex.axis=0.9, cex=1, sfrac=0, ylim=c(-0.25,0.35))
rect(xleft=0, ybottom=-0.3, xright=2.5, ytop=0.4, col=rgb(255, 153, 51,50, maxColorValue=255), border=NA)
abline(h=0)
abline(v=2.5, lty=2)
abline(v=4.5, lty=2)
abline(v=6.5, lty=2)
abline(v=8.5, lty=2)
abline(v=10.5, lty=2)
abline(v=12.5, lty=2)
mtext(text=labs, las=1, side=1, at=c(1.5, 3.5, 5.5, 7.5, 9.5, 11.5, 13.5), line=0.5, cex=0.9, padj=1)
legend(12, 0.35, c("Fixed effects", "Random effects"), cex=0.8, pch=c(21,15), pt.bg=c("blue3", "forestgreen"), col=c("blue3", "forestgreen"), bg="white", bty="o")
# Number of studies
text(1.5,-0.25,labels=paste0("N=", main_results_no_inoutgroup$k_for_graph[1]))
text(3.5,-0.25,labels=paste0("N=", main_results_no_inoutgroup$k_for_graph[3]))
text(5.5,-0.25,labels=paste0("N=", main_results_no_inoutgroup$k_for_graph[5]))
text(7.5,-0.25,labels=paste0("N=", main_results_no_inoutgroup$k_for_graph[7]))
text(9.5,-0.25,labels=paste0("N=", main_results_no_inoutgroup$k_for_graph[9]))
text(11.5,-0.25,labels=paste0("N=", main_results_no_inoutgroup$k_for_graph[11]))
text(13.5,-0.25,labels=paste0("N=", main_results_no_inoutgroup$k_for_graph[13]))
# Coefficeints
text(0.7,main_results_no_inoutgroup$beta_for_graph[1],labels=substr(paste0(round(main_results_no_inoutgroup$beta_for_graph[1],2)), 2, nchar(paste0(round(main_results_no_inoutgroup$beta_for_graph[1],2)))), cex=0.7, col="blue3")
text(1.7,main_results_no_inoutgroup$beta_for_graph[2],labels=substr(paste0(round(main_results_no_inoutgroup$beta_for_graph[2],2)), 2, nchar(paste0(round(main_results_no_inoutgroup$beta_for_graph[2],2)))), cex=0.7, col="forestgreen")
text(2.7,main_results_no_inoutgroup$beta_for_graph[3],labels=substr(paste0(round(main_results_no_inoutgroup$beta_for_graph[3],2)), 2, nchar(paste0(round(main_results_no_inoutgroup$beta_for_graph[3],2)))), cex=0.7, col="blue3")
text(3.7,main_results_no_inoutgroup$beta_for_graph[4],labels=substr(paste0(round(main_results_no_inoutgroup$beta_for_graph[4],2)), 2, nchar(paste0(round(main_results_no_inoutgroup$beta_for_graph[4],2)))), cex=0.7, col="forestgreen")
text(4.7,main_results_no_inoutgroup$beta_for_graph[5],labels=substr(paste0(round(main_results_no_inoutgroup$beta_for_graph[5],2)), 2, nchar(paste0(round(main_results_no_inoutgroup$beta_for_graph[5],2)))), cex=0.7, col="blue3")
text(5.7,main_results_no_inoutgroup$beta_for_graph[6],labels=substr(paste0(round(main_results_no_inoutgroup$beta_for_graph[6],2)), 2, nchar(paste0(round(main_results_no_inoutgroup$beta_for_graph[6],2)))), cex=0.7, col="forestgreen")
text(6.7,main_results_no_inoutgroup$beta_for_graph[7],labels=paste0(round(main_results_no_inoutgroup$beta_for_graph[7],2)), cex=0.7, col="blue3")
text(7.7,main_results_no_inoutgroup$beta_for_graph[8],labels=paste0("-",substr(paste0(round(main_results_no_inoutgroup$beta_for_graph[8],2)), 3, nchar(paste0(round(main_results_no_inoutgroup$beta_for_graph[8],2))))), cex=0.7, col="forestgreen")
text(8.7,main_results_no_inoutgroup$beta_for_graph[9],labels=substr(paste0(round(main_results_no_inoutgroup$beta_for_graph[9],2)), 2, nchar(paste0(round(main_results_no_inoutgroup$beta_for_graph[9],2)))), cex=0.7, col="blue3")
text(9.7,main_results_no_inoutgroup$beta_for_graph[10],labels=substr(paste0(round(main_results_no_inoutgroup$beta_for_graph[10],2)), 2, nchar(paste0(round(main_results_no_inoutgroup$beta_for_graph[10],2)))), cex=0.7, col="forestgreen")
text(10.7,main_results_no_inoutgroup$beta_for_graph[11],labels=substr(paste0(round(main_results_no_inoutgroup$beta_for_graph[11],2)), 2, nchar(paste0(round(main_results_no_inoutgroup$beta_for_graph[11],2)))), cex=0.7, col="blue3")
text(11.7,main_results_no_inoutgroup$beta_for_graph[12],labels=paste0("-",substr(paste0(round(main_results_no_inoutgroup$beta_for_graph[12],2)), 3, nchar(paste0(round(main_results_no_inoutgroup$beta_for_graph[12],2))))), cex=0.7, col="forestgreen")
text(12.7,main_results_no_inoutgroup$beta_for_graph[13],labels=substr(paste0(round(main_results_no_inoutgroup$beta_for_graph[13],2)), 2, nchar(paste0(round(main_results_no_inoutgroup$beta_for_graph[13],2)))), cex=0.7, col="blue3")
text(13.7,main_results_no_inoutgroup$beta_for_graph[14],labels=substr(paste0(round(main_results_no_inoutgroup$beta_for_graph[14],2)), 2, nchar(paste0(round(main_results_no_inoutgroup$beta_for_graph[14],2)))), cex=0.7, col="forestgreen")

dev.off()


# With crime violence

main_results <- read.csv("Results/Tables/main_results_percise_with_crime.csv")

main_results_no_index <-  main_results[main_results$outcome!="prosocial_index",]
main_results_index_only <- main_results[main_results$outcome=="prosocial_index",]

main_results_reordered <- rbind(main_results_index_only, main_results_no_index)


main_results_no_inoutgroup <- main_results_reordered[!(main_results_reordered$outcome %in% c("trust_ingroup", "trust_outgroup", "games_ingroup", "games_outgroup")) ,]



labs <- c("Summary \nindex", "Social \ngroup \nparticipation","Community \nleadership/ \nparticipation", "Trust", "Prosocial in \nexperimental \ngames", "Voting", "Knowledge/ \ninterest \nin politics")

pdf("Results/Figures/main_results_with_crime.pdf", width=8, height=5)

par(mar=c(5,4,2,2))
plotCI(x= main_results_no_inoutgroup$beta_for_graph, ui= main_results_no_inoutgroup$ci.ub_for_graph, li= main_results_no_inoutgroup$ci.lb_for_graph, type="p", pt.bg= c("blue3", "forestgreen", "blue3", "forestgreen", "blue3", "forestgreen", "blue3", "forestgreen", "blue3", "forestgreen", "blue3", "forestgreen", "blue3", "forestgreen") , col=c("blue3", "forestgreen", "blue3", "forestgreen", "blue3", "forestgreen", "blue3", "forestgreen", "blue3", "forestgreen", "blue3", "forestgreen", "blue3", "forestgreen"), pch=c(21, 15, 21, 15, 21, 15, 21, 15, 21, 15, 21, 15, 21, 15), gap=0, xaxt="n", ylab="Effect of exposure to violence (sd units)", xlab="", cex.main=1, cex.axis=0.9, cex=1, sfrac=0)
rect(xleft=0, ybottom=-0.3, xright=2.5, ytop=0.4, col=rgb(255, 153, 51,50, maxColorValue=255), border=NA)
abline(h=0)
abline(v=2.5, lty=2)
abline(v=4.5, lty=2)
abline(v=6.5, lty=2)
abline(v=8.5, lty=2)
abline(v=10.5, lty=2)
abline(v=12.5, lty=2)
mtext(text=labs, las=1, side=1, at=c(1.5, 3.5, 5.5, 7.5, 9.5, 11.5, 13.5), line=0.5, cex=0.9, padj=1)
legend(11.5, 0.32, c("Fixed effects", "Random effects"), cex=0.8, pch=c(21,15), pt.bg=c("blue3", "forestgreen"), col=c("blue3", "forestgreen"), bg="white", bty="o")
text(1.5,-0.2,labels=paste0("N=", main_results_no_inoutgroup$k_for_graph[1]))
text(3.5,-0.2,labels=paste0("N=", main_results_no_inoutgroup$k_for_graph[3]))
text(5.5,-0.2,labels=paste0("N=", main_results_no_inoutgroup$k_for_graph[5]))
text(7.5,-0.2,labels=paste0("N=", main_results_no_inoutgroup$k_for_graph[7]))
text(9.5,-0.2,labels=paste0("N=", main_results_no_inoutgroup$k_for_graph[9]))
text(11.5,-0.2,labels=paste0("N=", main_results_no_inoutgroup$k_for_graph[11]))
text(13.5,-0.2,labels=paste0("N=", main_results_no_inoutgroup$k_for_graph[13]))

dev.off()