# Test for whether different between in-group vs. out-group is significant

# Trust
#######

trust_test <- results_viol_exp_dummy[grep("trustingroup_std|trustoutgroup_std", names(results_viol_exp_dummy))]


# Extract beta coefficients

coefs_trust_test <- rep(NA, length(trust_test))
for (i in 1:length(trust_test)){
	coefs_trust_test[i] <- trust_test[[i]]$estimate[1]
}

# Exctract standard errors

se_trust_test <- rep(NA, length(trust_test))
for (i in 1:length(trust_test)){
	se_trust_test[i] <- trust_test[[i]]$stderr[1]
}


# Extract number of observations

ns_trust_test <- rep(NA, length(trust_test))
for (i in 1:length(trust_test)){
	ns_trust_test[i] <- trust_test[[i]]$es_1[1]
}


# Create data frames for results

trust_test_df <- cbind(as.data.frame(coefs_trust_test), se_trust_test, ns_trust_test)
trust_test_df$treatment <- "viol_exp_dummy"
trust_test_df$study <- names(trust_test)
trust_test_df$ingroup <- NA
trust_test_df$ingroup[grep("trustingroup_std", trust_test_df$study)] <- 1
trust_test_df$ingroup[grep("trustoutgroup_std", trust_test_df$study)] <- 0

# exclude crime
trust_test_df <- trust_test_df[-c(3,4,5),]
colnames(trust_test_df) <- c("coef", "se", "n", "treatment", "study", "ingroup")

trust_test_escalc <- escalc(measure="COR", ri=coef, sdi=sd, ni= n, data= trust_test_df)
trust_test_fe <- rma(yi, vi, mods = ~ ingroup, data = trust_test_escalc, method = "FE", measure="COR")
trust_test_re <- rma(yi, vi, mods = ~ ingroup, data = trust_test_escalc, method = "REML", measure="COR")

print(trust_test_fe)
print(trust_test_re)

# Games
########

games_test <- results_viol_exp_dummy[grep("gamesingroup|_cooperate_std|dict_sent_std|_s_sent_std|_sharereturn_std|_social_prefereces_std|gamesoutgroup|dictator_stdingroup|dictator_stdoutgroup", names(results_viol_exp_dummy))]

# Extract beta coefficients

coefs_games_test <- rep(NA, length(games_test))
for (i in 1:length(games_test)){
	coefs_games_test[i] <- games_test[[i]]$estimate[1]
}

# Exctract standard errors

se_games_test <- rep(NA, length(games_test))
for (i in 1:length(games_test)){
	se_games_test[i] <- games_test[[i]]$stderr[1]
}


# Extract number of observations

ns_games_test <- rep(NA, length(games_test))
for (i in 1:length(games_test)){
	ns_games_test[i] <- games_test[[i]]$es_1[1]
}

# Create data frames for results

games_test_df <- cbind(as.data.frame(coefs_games_test), se_games_test, ns_games_test)
games_test_df$treatment <- "viol_exp_dummy"
games_test_df$study <- names(games_test)
games_test_df$ingroup <- NA
games_test_df$ingroup[grep("gamesingroup|_cooperate_std|dict_sent_std|_s_sent_std|_sharereturn_std|_social_prefereces_std|dictator_stdingroup", games_test_df$study)] <- 1
games_test_df$ingroup[grep("gamesoutgroup|dictator_stdoutgroup", games_test_df$study)] <- 0
colnames(games_test_df) <- c("coef", "se", "n", "treatment", "study", "ingroup")


games_test_escalc <- escalc(measure="COR", ri=coef, sdi=sd, ni= n, data= games_test_df)
games_test_fe <- rma(yi, vi, mods = ~ ingroup, data = games_test_escalc, method = "FE", measure="COR")
games_test_re <- rma(yi, vi, mods = ~ ingroup, data = games_test_escalc, method = "REML", measure="COR")

print(games_test_fe)
print(games_test_re)




