## This code examines heterogeneity in effects as a function of various study level covariates
## The dependent variable is a prosocial index of all outcomes
library(xtable)

prosocial_indexM_results_viol_exp_dummy = read.csv("Temp/heterogeneity.csv")

meta.prosocial_indexM <- escalc(measure="COR", ri=coef, sdi=se, ni= n, data= prosocial_indexM_results_viol_exp_dummy, vtype="LS")

# data frame with crime
meta.prosocial_indexM_crime <- meta.prosocial_indexM

# data frame removing crime
meta.prosocial_indexM <- meta.prosocial_indexM[-c(2,3,4,5),]


### A. Causal inference covariates ### (exclude crime)


# Correlation between causal inference covariates

corr_causal <- cor(x=cbind(meta.prosocial_indexM$Substantive.controls, meta.prosocial_indexM$Regression.with.controls.and.community.FE, meta.prosocial_indexM$Pre.war.data, meta.prosocial_indexM$Sensitivity.analysis, meta.prosocial_indexM$Instrumental.variables))
colnames(corr_causal) = rownames(corr_causal) = c("Substantive controls", "FE design", "Pre-war data", "Sensitivity", "IV")
xtable(corr_causal)
write.csv(corr_causal, file="Results/Tables/corr_causal_inf_covars.csv")


# Meta analysis results with causal inference covariates

meta.out.fe <- rma(yi, vi, mods=~ Substantive.controls + Regression.with.controls.and.community.FE + Pre.war.data + Sensitivity.analysis + Instrumental.variables, data = meta.prosocial_indexM, method = "FE", measure="COR", slab=authoryear)
meta.out.re <- rma(yi, vi, mods=~ Substantive.controls + Regression.with.controls.and.community.FE + Pre.war.data + Sensitivity.analysis + Instrumental.variables, data = meta.prosocial_indexM, method = "REML", measure="COR", slab=authoryear)

mod.fe = round(cbind(meta.out.fe$b, meta.out.fe$se, meta.out.fe$pval), 2)
mod.re = round(cbind(meta.out.re$b, meta.out.re$se, meta.out.re$pval), 2)


results = cbind(mod.fe, mod.re)
colnames(results) = c("Coefficient", "Std. Err.", "p-value", "Coefficient", "Std. Err.", "p-value")
rownames(results) = c("Intercept", "Substantive controls", "FE design", "Pre-war data", "Sensitivity", "Instrumental variables")
xtable(results)
write.csv(results, file="Results/Tables/meta_analysis_results_causal_inf_covars.csv")


### B. Other study-level covariates ### (bivariate analysis)

# Personal exposure
meta.out.fe.personal <- rma(yi, vi, mods=~ personal_exposure, data = meta.prosocial_indexM, method = "FE", measure="COR", slab=authoryear)
meta.out.re.personal <- rma(yi, vi, mods=~ personal_exposure, data = meta.prosocial_indexM, method = "REML", measure="COR", slab=authoryear)
mod.fe.personal = round(cbind(meta.out.fe.personal$b, meta.out.fe.personal$se, meta.out.fe.personal$pval), 2)
mod.re.personal = round(cbind(meta.out.re.personal$b, meta.out.re.personal$se, meta.out.re.personal$pval), 2)
personal = cbind(mod.fe.personal, mod.re.personal)


# Years since war
meta.out.fe.years <- rma(yi, vi, mods=~ years_since_war, data = meta.prosocial_indexM, method = "FE", measure="COR", slab=authoryear)
meta.out.re.years <- rma(yi, vi, mods=~ years_since_war, data = meta.prosocial_indexM, method = "REML", measure="COR", slab=authoryear)
mod.fe.years = round(cbind(meta.out.fe.years$b, meta.out.fe.years$se, meta.out.fe.years$pval), 2)
mod.re.years = round(cbind(meta.out.re.years$b, meta.out.re.years$se, meta.out.re.years$pval), 2)
years = cbind(mod.fe.years, mod.re.years)


# Civilian vs. combatant
meta.out.fe.civilian <- rma(yi, vi, mods=~ civilian, data = meta.prosocial_indexM, method = "FE", measure="COR", slab=authoryear)
meta.out.re.civilian <- rma(yi, vi, mods=~ civilian, data = meta.prosocial_indexM, method = "REML", measure="COR", slab=authoryear)
mod.fe.civilian = round(cbind(meta.out.fe.civilian$b, meta.out.fe.civilian$se, meta.out.fe.civilian$pval), 2)
mod.re.civilian = round(cbind(meta.out.re.civilian$b, meta.out.re.civilian$se, meta.out.re.civilian$pval), 2)
civilian = cbind(mod.fe.civilian, mod.re.civilian)

# Crime
meta.out.fe.crime <- rma(yi, vi, mods=~ crime, data = meta.prosocial_indexM_crime, method = "FE", measure="COR", slab=authoryear)
meta.out.re.crime <- rma(yi, vi, mods=~ crime, data = meta.prosocial_indexM_crime, method = "REML", measure="COR", slab=authoryear)
mod.fe.crime = round(cbind(meta.out.fe.crime$b, meta.out.fe.crime$se, meta.out.fe.crime$pval), 2)
mod.re.crime = round(cbind(meta.out.re.crime$b, meta.out.re.crime$se, meta.out.re.crime$pval), 2)
crime = cbind(mod.fe.crime, mod.re.crime)

# Region
meta.out.fe.region <- rma(yi, vi, mods=~  asia + europe, data = meta.prosocial_indexM, method = "FE", measure="COR", slab=authoryear)
meta.out.re.region <- rma(yi, vi, mods=~  asia + europe, data = meta.prosocial_indexM, method = "REML", measure="COR", slab=authoryear)
mod.fe.region = round(cbind(meta.out.fe.region$b, meta.out.fe.region$se, meta.out.fe.region$pval), 2)
mod.re.region = round(cbind(meta.out.re.region$b, meta.out.re.region$se, meta.out.re.region$pval), 2)
region = cbind(mod.fe.region, mod.re.region)

results = rbind(personal, years, civilian, crime, region)
colnames(results) = c("Coefficient", "Std. Err.", "p-value", "Coefficient", "Std. Err.", "p-value")
rownames(results) = c("Intercept", "Personal exposure", "Intercept ", "Years since war", "Intercept  ", "Civilian", "Intercept   ", "Crime", "Intercept (Africa)", "Asia", "Europe")
library(xtable)
xtable(results)
write.csv(results, file="Results/Tables/meta_analysis_results_other_covars.csv")



### C. Meta analytic scatterplots ### 

## Persistence and crime (random effects)

pdf("Results/Figures/persistence_crime_re.pdf", width=8, height=5)

par(mfrow=c(1,2))

### Persistence

preds <- predict(meta.out.re.years, newmods=c(0:15))

wi    <- 1/sqrt(meta.out.re.years$vi)
size  <- 0.5 + 3.0 * (wi - min(wi))/(max(wi) - min(wi))
 
plot(meta.prosocial_indexM$years_since_war, meta.prosocial_indexM$yi, pch=19, cex=size, 
     xlab="Years since war", ylab="Effect of exposure to violence (sd units)",
     las=1, bty="l", ylim=c(-0.2,0.2), main="A. Persistence \n(random effects)", col="blue", cex.main=0.8)
 
lines(0:15, preds$pred)
lines(0:15, preds$ci.lb, lty="dashed")
lines(0:15, preds$ci.ub, lty="dashed")


### Crime

preds <- predict(meta.out.re.crime, newmods=c(0:1))
 
wi    <- 1/sqrt(meta.out.re.crime$vi)
size  <- 0.5 + 3.0 * (wi - min(wi))/(max(wi) - min(wi))
 
plot(meta.prosocial_indexM_crime$crime, meta.prosocial_indexM_crime$yi, pch=19, cex=size, 
     xlab="", ylab="Effect of exposure to violence (sd units)",
     las=1, bty="l", ylim=c(-0.2,0.2), xaxt="n", xlim=c(-0.1, 1.1), main="B. War vs. crime violence \n(random effects)", col="blue", cex.main=0.8)
mtext(text=c("War \nviolence \nexposure", "Crime \nviolence \nexposure"), las=1, side=1, at=c(0,1), line=0.5, cex=0.9, padj=1)
 
lines(0:1, preds$pred)
lines(0:1, preds$ci.lb, lty="dashed")
lines(0:1, preds$ci.ub, lty="dashed")


dev.off()


## Persistence and crime (fixed effects)

pdf("Results/Figures/persistence_crime_fe.pdf", width=8, height=5)

par(mfrow=c(1,2))

### Persistence

preds <- predict(meta.out.fe.years, newmods=c(0:15))

wi    <- 1/sqrt(meta.out.fe.years$vi)
size  <- 0.5 + 3.0 * (wi - min(wi))/(max(wi) - min(wi))
 
plot(meta.prosocial_indexM$years_since_war, meta.prosocial_indexM$yi, pch=19, cex=size, 
     xlab="Years since war", ylab="Effect of exposure to violence (sd units)",
     las=1, bty="l", ylim=c(-0.2,0.2), main="A. Persistence \n(fixed effects)", col="blue", cex.main=0.8)
 
lines(0:15, preds$pred)
lines(0:15, preds$ci.lb, lty="dashed")
lines(0:15, preds$ci.ub, lty="dashed")


### Crime

preds <- predict(meta.out.fe.crime, newmods=c(0:1))
 
wi    <- 1/sqrt(meta.out.fe.crime$vi)
size  <- 0.5 + 3.0 * (wi - min(wi))/(max(wi) - min(wi))
 
plot(meta.prosocial_indexM_crime$crime, meta.prosocial_indexM_crime$yi, pch=19, cex=size, 
     xlab="", ylab="Effect of exposure to violence (sd units)",
     las=1, bty="l", ylim=c(-0.2,0.2), xaxt="n", xlim=c(-0.1, 1.1), main="B. War vs. crime violence \n(fixed effects)", col="blue", cex.main=0.8)
mtext(text=c("War \nviolence \nexposure", "Crime \nviolence \nexposure"), las=1, side=1, at=c(0,1), line=0.5, cex=0.9, padj=1)
 
lines(0:1, preds$pred)
lines(0:1, preds$ci.lb, lty="dashed")
lines(0:1, preds$ci.ub, lty="dashed")


dev.off()


## Empirical strategy


pdf("Results/Figures/empirical_strategy.pdf", width=8, height=5)

par(mfrow=c(1,2))

meta.out.fe.empirical.strategy <- rma(yi, vi, mods=~  causal_inference, data = meta.prosocial_indexM, method = "FE", measure="COR", slab=authoryear)

preds <- predict(meta.out.fe.empirical.strategy, newmods=seq(0,1, 0.1))

wi    <- 1/sqrt(meta.prosocial_indexM$vi)
size  <- 0.5 + 3.0 * (wi - min(wi))/(max(wi) - min(wi))
 
plot(meta.prosocial_indexM$causal_inference, meta.prosocial_indexM$yi, pch=19, cex=size, 
     xlab="Causal inference scale", ylab="Effect of exposure to violence (sd units)",
     las=1, bty="l", ylim=c(-0.2,0.2), main="Fixed Effects Model", col="blue", cex.main=0.8)

lines(seq(0,1, 0.1), preds$pred)
lines(seq(0,1, 0.1), preds$ci.lb, lty="dashed")
lines(seq(0,1, 0.1), preds$ci.ub, lty="dashed")


meta.out.re.empirical.strategy <- rma(yi, vi, mods=~  causal_inference, data = meta.prosocial_indexM, method = "REML", measure="COR", slab=authoryear)

preds <- predict(meta.out.re.empirical.strategy, newmods=seq(0,1, 0.1))

wi    <- 1/sqrt(meta.prosocial_indexM$vi)
size  <- 0.5 + 3.0 * (wi - min(wi))/(max(wi) - min(wi))
 
plot(meta.prosocial_indexM$causal_inference, meta.prosocial_indexM$yi, pch=19, cex=size, 
     xlab="Causal inference scale", ylab="Effect of exposure to violence (sd units)",
     las=1, bty="l", ylim=c(-0.2,0.2), main="Random Effects Model", col="blue", cex.main=0.8)

lines(seq(0,1, 0.1), preds$pred)
lines(seq(0,1, 0.1), preds$ci.lb, lty="dashed")
lines(seq(0,1, 0.1), preds$ci.ub, lty="dashed")

dev.off()
