############

# H. Voting

############


voting_viol_exp_community_std <- results_viol_exp_community_std[grep("voting_std", names(results_viol_exp_community_std))]


# Extract beta coefficients

coefs_voting_viol_exp_community_std <- rep(NA, length(voting_viol_exp_community_std))
for (i in 1:length(voting_viol_exp_community_std)){
	coefs_voting_viol_exp_community_std[i] <- voting_viol_exp_community_std[[i]]$estimate[1]
}

# Exctract standard errors

se_voting_viol_exp_community_std <- rep(NA, length(voting_viol_exp_community_std))
for (i in 1:length(voting_viol_exp_community_std)){
	se_voting_viol_exp_community_std[i] <- voting_viol_exp_community_std[[i]]$stderr[1]
}


# Extract number of observations

ns_voting_viol_exp_community_std <- rep(NA, length(voting_viol_exp_community_std))
for (i in 1:length(voting_viol_exp_community_std)){
	ns_voting_viol_exp_community_std[i] <- voting_viol_exp_community_std[[i]]$es_1[1]
}


# Create data frames for results

voting_results_viol_exp_community_std <- cbind(as.data.frame(coefs_voting_viol_exp_community_std), se_voting_viol_exp_community_std, ns_voting_viol_exp_community_std)
voting_results_viol_exp_community_std$treatment <- "viol_exp_community_std"
voting_results_viol_exp_community_std$study <- names(voting_viol_exp_community_std)
voting_results_viol_exp_community_std$country <- c("Uganda", "Sierra Leone", "Uganda", "Sierra Leone", "Uganda", "Tajikistan", "Uganda", "European countries", "Burundi")
voting_results_viol_exp_community_std$authoryear <- c("Annan et al. (2011)",  "Bauer et al. (2014)", "Bauer et al. (2014) ", "Bellows and Miguel (2009)", "Blattman (2009)", "Cassar et al. (2013)", "De Luca and Verpoorten (2015b)", "Grosjean (2014)", "Voors et al. (2012)")
colnames(voting_results_viol_exp_community_std) <- c("coef", "se", "n", "treatment", "study", "country", "authoryear")


voting_results <- voting_results_viol_exp_community_std

# Forest plot

pdf("Results/Figures/Forest_plot_std_community_measure_no_crime/forest_plot_voting_FE.pdf", width=6, height=5)

par(mar=c(4,4,1,2))

meta.voting <- escalc(measure="COR", ri=coef, sdi=se, ni= n, data= voting_results, vtype="LS")

# fit a FE model
meta.voting.out <- rma(yi, vi, data = meta.voting, method = "FE", measure="COR", slab=authoryear)

# plot a forest plot
forest(meta.voting.out, ilab= meta.voting$country, ilab.xpos=-1.5, ilab.pos=4, xlim=c(-3,2), xlab="Standardized coefficient", cex=0.7, addfit=T, mlab="FE Model for All Studies")



### add column headings to the plot
text(-3, 10.5, "Author(s) and Year", pos=4, cex=0.75, font=2)
text(-1.5, 10.5, "Country", pos=4, cex=0.75, font=2)
text(0.8, 10.5, "Coefficient [95% CI]", pos=4, cex=0.75, font=2)
text(-3, 11.5, "Voting", pos=4, cex=0.85, font=2)


dev.off()

main_result_voting_fe <- rma(yi, vi, data = meta.voting, method = "FE", measure="COR", slab=authoryear, subset=(treatment=="viol_exp_community_std"))


