########################################

# B. Community leadership/participation

########################################


community_viol_exp_std <- results_viol_exp_std[grep("communityparticipation_std", names(results_viol_exp_std))]

# Extract beta coefficients

coefs_community_viol_exp_std <- rep(NA, length(community_viol_exp_std))
for (i in 1:length(community_viol_exp_std)){
	coefs_community_viol_exp_std[i] <- community_viol_exp_std[[i]]$estimate[1]
}

# Exctract standard errors

se_community_viol_exp_std <- rep(NA, length(community_viol_exp_std))
for (i in 1:length(community_viol_exp_std)){
	se_community_viol_exp_std[i] <- community_viol_exp_std[[i]]$stderr[1]
}

# Extract number of observations

ns_community_viol_exp_std <- rep(NA, length(community_viol_exp_std))
for (i in 1:length(community_viol_exp_std)){
	ns_community_viol_exp_std[i] <- community_viol_exp_std[[i]]$es_1[1]
}


# Create data frames for results

community_results_viol_exp_std <- cbind(as.data.frame(coefs_community_viol_exp_std), se_community_viol_exp_std, ns_community_viol_exp_std)
community_results_viol_exp_std$treatment <- "viol_exp_std"
community_results_viol_exp_std$study <- names(community_viol_exp_std)
community_results_viol_exp_std$country <- c("Uganda", "African countries", "Latin American countries", "U.S. and Canada", "Sierra Leone", "Uganda", "Sierra Leone", "Uganda", "Tajikistan", "Uganda", "Burundi")
community_results_viol_exp_std$authoryear <- c("Annan et al. (2011)", "Bateson (2012)", "Bateson (2012) ", "Bateson (2012)  ", "Bauer et al. (2014)", "Bauer et al. (2014) ", "Bellows and Miguel (2009)", "Blattman (2009)", "Cassar et al. (2013)", "De Luca and Verpoorten (2015b)", "Voors et al. (2012)")
colnames(community_results_viol_exp_std) <- c("coef", "se", "n", "treatment", "study", "country", "authoryear")


community_results <- community_results_viol_exp_std[-c(2,3,4),]

# Forest plot

pdf("Results/Figures/Forest_plot_std_measure_no_crime/forest_plot_community_FE.pdf", width=6, height=5)

par(mar=c(4,4,1,2))

meta.community <- escalc(measure="COR", ri=coef, sdi=se, ni= n, data= community_results, vtype="LS")

# fit a FE model
meta.community.out <- rma(yi, vi, data = meta.community, method = "FE", measure="COR", slab=authoryear)

# plot a forest plot
forest(meta.community.out, ilab= meta.community$country, ilab.xpos=-1.5, ilab.pos=4, xlim=c(-3,2),  xlab="Standardized coefficient", cex=0.7, addfit=T, mlab="FE Model for All Studies")



### add column headings to the plot
text(-3, 9.5, "Author(s) and Year", pos=4, cex=0.75, font=2)
text(-1.5, 9.5, "Country", pos=4, cex=0.75, font=2)
text(0.8, 9.5, "Coefficient [95% CI]", pos=4, cex=0.75, font=2)
text(-3, 10.8, "Community Leadership/Participation", pos=4, cex=0.85, font=2)


dev.off()

main_result_community_fe <- rma(yi, vi, data = meta.community, method = "FE", measure="COR", slab=authoryear, subset=(treatment=="viol_exp_std"))
