##################

# E. Trust (all)

#################

trust_viol_exp_std <- results_viol_exp_std[grep("trustall_std", names(results_viol_exp_std))]

# Extract beta coefficients

coefs_trust_viol_exp_std <- rep(NA, length(trust_viol_exp_std))
for (i in 1:length(trust_viol_exp_std)){
	coefs_trust_viol_exp_std[i] <- trust_viol_exp_std[[i]]$estimate[1]
}


# Exctract standard errors

se_trust_viol_exp_std <- rep(NA, length(trust_viol_exp_std))
for (i in 1:length(trust_viol_exp_std)){
	se_trust_viol_exp_std[i] <- trust_viol_exp_std[[i]]$stderr[1]
}


# Extract number of observations

ns_trust_viol_exp_std <- rep(NA, length(trust_viol_exp_std))
for (i in 1:length(trust_viol_exp_std)){
	ns_trust_viol_exp_std[i] <- trust_viol_exp_std[[i]]$es_1[1]
}



# Create data frames for results

trust_results_viol_exp_std <- cbind(as.data.frame(coefs_trust_viol_exp_std), se_trust_viol_exp_std, ns_trust_viol_exp_std)
trust_results_viol_exp_std$treatment <- "viol_exp_std"
trust_results_viol_exp_std$study <- names(trust_viol_exp_std)
trust_results_viol_exp_std$country <- c("Uganda", "African countries", "Sierra Leone", "Uganda", "Sierra Leone", "Tajikistan", "Uganda", "European countries", "Uganda", "Burundi")
trust_results_viol_exp_std$authoryear <- c("Annan et al. (2011)", "Bateson (2012)", "Bauer et al. (2014)", "Bauer et al. (2014) ", "Bellows and Miguel (2009)", "Cassar et al. (2013)", "De Luca and Verpoorten (2015a)", "Grosjean (2014)", "Rohner et al. (2013)", "Voors and Bulte (2014)")
colnames(trust_results_viol_exp_std) <- c("coef", "se", "n", "treatment", "study", "country", "authoryear")


trust_results <- trust_results_viol_exp_std[-2,]

# Forest plot

pdf("Results/Figures/Forest_plot_std_measure_no_crime/forest_plot_trust_all_RE.pdf", width=6, height=5)

par(mar=c(4,4,1,2))

meta.trust <- escalc(measure="COR", ri=coef, sdi=se, ni= n, data= trust_results, vtype="LS")

# fit a FE model
meta.trust.out <- rma(yi, vi, data = meta.trust, method = "REML", measure="COR", slab=authoryear)

# plot a forest plot
forest(meta.trust.out, ilab= meta.trust$country, ilab.xpos=-1.5, ilab.pos=4, xlim=c(-3,2), xlab="Standardized coefficient", cex=0.7, addfit=T, mlab="RE Model for All Studies")


### add column headings to the plot
text(-3, 10.5, "Author(s) and Year", pos=4, cex=0.75, font=2)
text(-1.5, 10.5, "Country", pos=4, cex=0.75, font=2)
text(0.8, 10.5, "Coefficient [95% CI]", pos=4, cex=0.75, font=2)
text(-3, 11.5, "Trust (All types)", pos=4, cex=0.85, font=2)

dev.off()

main_result_trust_all_re <- rma(yi, vi, data = meta.trust, method = "REML", measure="COR", slab=authoryear, subset=(treatment=="viol_exp_std"))
