
###################

# C. Trust ingroup

###################

trust_viol_exp_personal_std <- results_viol_exp_personal_std[grep("trustingroup_std", names(results_viol_exp_personal_std))]

# Extract beta coefficients

coefs_trust_viol_exp_personal_std <- rep(NA, length(trust_viol_exp_personal_std))
for (i in 1:length(trust_viol_exp_personal_std)){
	coefs_trust_viol_exp_personal_std[i] <- trust_viol_exp_personal_std[[i]]$estimate[1]
}

# Exctract standard errors

se_trust_viol_exp_personal_std <- rep(NA, length(trust_viol_exp_personal_std))
for (i in 1:length(trust_viol_exp_personal_std)){
	se_trust_viol_exp_personal_std[i] <- trust_viol_exp_personal_std[[i]]$stderr[1]
}


# Extract number of observations

ns_trust_viol_exp_personal_std <- rep(NA, length(trust_viol_exp_personal_std))
for (i in 1:length(trust_viol_exp_personal_std)){
	ns_trust_viol_exp_personal_std[i] <- trust_viol_exp_personal_std[[i]]$es_1[1]
}


# Create data frames for results

trust_results_viol_exp_personal_std <- cbind(as.data.frame(coefs_trust_viol_exp_personal_std), se_trust_viol_exp_personal_std, ns_trust_viol_exp_personal_std)
trust_results_viol_exp_personal_std$treatment <- "viol_exp_personal_std"
trust_results_viol_exp_personal_std$study <- names(trust_viol_exp_personal_std)
trust_results_viol_exp_personal_std$country <- c("Uganda", "African countries", "Asian countries", "Sierra Leone", "Uganda")
trust_results_viol_exp_personal_std$authoryear <- c("Annan et al. (2011)", "Bateson (2012)", "Bateson (2012)  ", "Bauer et al. (2014)", "Bauer et al. (2014) ")
colnames(trust_results_viol_exp_personal_std) <- c("coef", "se", "n", "treatment", "study", "country", "authoryear")

trust_results <- trust_results_viol_exp_personal_std[-c(2,3),]


# Forest plot

pdf("Results/Figures/Forest_plot_std_personal_measure_no_crime/forest_plot_trust_ingroup_FE.pdf", width=6, height=5)

par(mar=c(4,4,1,2))

meta.trust <- escalc(measure="COR", ri=coef, sdi=se, ni= n, data= trust_results, vtype="LS")

# fit a FE model
meta.trust.out <- rma(yi, vi, data = meta.trust, method = "FE", measure="COR", slab=authoryear)

# plot a forest plot
forest(meta.trust.out, ilab= meta.trust$country, ilab.xpos=-1.5, ilab.pos=4, xlim=c(-3,2), xlab="Standardized coefficient", cex=0.7, addfit=T, mlab="FE Model for All Studies")



### add column headings to the plot
text(-3, 4.5, "Author(s) and Year", pos=4, cex=0.75, font=2)
text(-1.5, 4.5, "Country", pos=4, cex=0.75, font=2)
text(0.8, 4.5, "Coefficient [95% CI]", pos=4, cex=0.75, font=2)
text(-3, 5.5, "In-group Trust", pos=4, cex=0.85, font=2)

dev.off()

main_result_trust_ingroup_fe <- rma(yi, vi, data = meta.trust, method = "FE", measure="COR", slab=authoryear, subset=(treatment=="viol_exp_personal_std"))

